###############   PSQF 6249 FA & SEM Example 3 using R   #############

# Set width of output and  number of digits to be printed
options("width"=140, "digits"=4) 

# Use this to turn off scientific notation: 
# "fixed notation will be preferred unless it is more than 'scipen' digits wide"
options(scipen=9)

# turn off stars for different alpha levels
options(show.signif.stars=FALSE)

#####  Check to see if packages are downloaded, install if not, then load  #####

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import xls or xlsx data as table

if (!require("expss")) install.packages("expss")
library(expss) # To add variable and value labels, sort

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files

if (!require("psych")) install.packages("psych")
library(psych) # To add summary functions

################################################################################

# Define variables for working directory and data name
filesave = "C:\\Dropbox/22_PSQF6249/FQOL and Partnership/"
filename = "FT2part.xlsx"
setwd(dir=filesave)

# Import partnership item-level data with labels
Example3 = read_excel(paste0(filesave,filename)) 
# Convert to data frame as data frame to use for analysis
Example3 = as.data.frame(Example3)

# Open external file to save results to
txtStart(file=paste0(filesave,"R_Example3_Reliability_Output.txt"))

################################################################################

# Create object for 11 child items
child11Vars = c("pi5","pi6","pi7","pi8","pi9","pi10","pi11","pi12","pi13","pi14","pi15")
# Create a data frame with only these 11 variables
child11Data = Example3[child11Vars]

print("11-Item Child Subscale")
print("Descriptives and Correlations using All Available Cases")
describe(x=child11Data)
cor(x=child11Data, use="pairwise.complete.obs", method="pearson")

print("11-Item Child Subscale")
print("Item Discriminations and Alpha Reliability using All Available Cases")
print(alpha(x=child11Data, use="pairwise"), digits=3)

# Create object for 9 child items removing items 10 and 14
child9Vars = c("pi5","pi6","pi7","pi8","pi9","pi11","pi12","pi13","pi15")
# Create a data frame with only these 11 variables
child9Data = Example3[child9Vars]

print("9-Item Child Subscale -- Drop Items 10 and 14")
print("Item Discriminations and Alpha Reliability using All Available Cases")
print(alpha(x=child9Data, use="pairwise"), digits=3)

txtComment(" ") # insert blank space in output

################################################################################

# Create object for 12 family items
fam12Vars = c("pi10","pi14","pi16","pi17","pi18","pi19","pi20","pi21","pi22","pi23","pi24","pi25")
# Create a data frame with only these 12 variables
fam12Data = Example3[fam12Vars]

print("12-Item Family Subscale")
print("Descriptives and Correlations using All Available Cases")
describe(x=fam12Data)
cor(x=fam12Data, use="pairwise.complete.obs", method="pearson")

print("12-Item Family Subscale")
print("Item Discriminations and Alpha Reliability using All Available Cases")
print(alpha(x=fam12Data, use="pairwise"), digits=3)

# Create object for 9 family items removing items 17, 18, and 19
fam9Vars = c("pi10","pi14","pi16","pi20","pi21","pi22","pi23","pi24","pi25")
# Create a data frame with only these 11 variables
fam9Data = Example3[fam9Vars]

print("9-Item Family Subscale -- Drop Items 17, 19, and 19")
print("Item Discriminations and Alpha Reliability using All Available Cases")
print(alpha(x=fam9Data, use="pairwise"), digits=3)

txtComment(" ") # insert blank space in output

################################################################################

# Close external file of saved results
txtStop()


